@@ -69,7 +69,7 @@ void init_collage_mode(void)
 					": No size restriction specified for collage.\n"
 					" You did specify a background however, so the\n"
 					" collage size has defaulted to the size of the image\n",
-					stdout);
+					stderr);
 			opt.limit_w = bg_w;
 			opt.limit_h = bg_h;
 		} else {
@@ -78,7 +78,7 @@ void init_collage_mode(void)
 					": No size restriction specified for collage.\n"
 					" - For collage mode, you need to specify width and height.\n"
 					" Using defaults (width 800, height 600)\n",
-					stdout);
+					stderr);
 			opt.limit_w = 800;
 			opt.limit_h = 600;
 		}
@@ -185,22 +185,24 @@ void init_collage_mode(void)
 		}
 	}
 	if (opt.verbose)
-		fputs("\n", stdout);
+		fputs("\n", stderr);
 
 	if (opt.output && opt.output_file) {
 		char output_buf[1024];
 		if (opt.output_dir)
 			snprintf(output_buf, 1024, "%s/%s", opt.output_dir, opt.output_file);
-		else
-			strncpy(output_buf, opt.output_file, 1024);
+		else {
+			strncpy(output_buf, opt.output_file, 1023);
+			output_buf[1023] = '\0';
+		}
 		gib_imlib_save_image(im_main, output_buf);
 		if (opt.verbose) {
 			int tw, th;
 
 			tw = gib_imlib_image_get_width(im_main);
 			th = gib_imlib_image_get_height(im_main);
-			fprintf(stdout, PACKAGE ": File saved as %s\n", output_buf);
-			fprintf(stdout,
+			fprintf(stderr, PACKAGE ": File saved as %s\n", output_buf);
+			fprintf(stderr,
 				"    - Image is %dx%d pixels and contains %d thumbnails\n",
 				tw, th, (tw / opt.thumb_w) * (th / opt.thumb_h));
 		}
